import logging
from requests.exceptions import HTTPError
from brian_dashboard_manager.grafana.utils.request import TokenRequest


logger = logging.getLogger(__name__)


def find_folder(token_request, title):
    folders = get_folders(token_request)
    try:
        folder = next(
            f for f in folders if f['title'].lower() == title.lower())
    except StopIteration:
        folder = None

    if not folder:
        logger.info(f'Created folder: {title}')
        folder = create_folder(token_request, title)
    return folder


def get_folders(request: TokenRequest):
    return request.get('api/folders')


def create_folder(request: TokenRequest, title):
    try:
        data = {'title': title, 'uid': title.replace(' ', '_')}
        r = request.post('api/folders', json=data)
    except HTTPError:
        logger.exception(f'Error when creating folder {title}')
        return None
    return r
